pecos.op\_processors.op\_processor\_abc
=======================================

.. automodule:: pecos.op_processors.op_processor_abc











   .. rubric:: Classes

   .. autosummary::

      OpProcessor
